@@ -5,10 +5,15 @@
 */
 
 #include "assetrepository_p.h"
+#include "logging.h"
+
+#include <KPublicTransport/Attribution>
 
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
+#include <QJsonArray>
+#include <QJsonDocument>
 #include <QNetworkAccessManager>
 #include <QNetworkReply>
 #include <QStandardPaths>
@@ -90,7 +95,7 @@ bool AssetRepository::isQueueEmpty()
 void AssetRepository::downloadNext()
 {
     if (m_queue.empty()) {
-        emit downloadFinished();
+        Q_EMIT downloadFinished();
         return;
     }
 
@@ -133,3 +138,18 @@ void AssetRepository::downloadNext()
         downloadNext();
     });
 }
+
+const std::vector<Attribution>& AssetRepository::attributions() const
+{
+    if (m_attributions.empty()) {
+        QFile f(QStringLiteral(":/org.kde.kpublictransport/assets/asset-attributions.json"));
+        if (!f.open(QFile::ReadOnly)) {
+            qCWarning(Log) << f.fileName() << f.errorString();
+            return m_attributions;
+        }
+
+        m_attributions = Attribution::fromJson(QJsonDocument::fromJson(f.readAll()).array());
+    }
+
+    return m_attributions;
+}
