@@ -9,6 +9,7 @@
 #include "logging.h"
 #include "datatypes/loadutil_p.h"
 #include "geo/polylinedecoder_p.h"
+#include "ifopt/ifoptutil.h"
 
 #include <KPublicTransport/Journey>
 #include <KPublicTransport/Platform>
@@ -239,6 +240,16 @@ std::vector<Location> HafasMgateParser::parseLocations(const QJsonArray &locL) c
         setLocationIdentifier(loc, locObj.value(QLatin1String("extId")).toString());
         const auto coordObj = locObj.value(QLatin1String("crd")).toObject();
         loc.setCoordinate(coordObj.value(QLatin1String("y")).toDouble() / 1000000.0, coordObj.value(QLatin1String("x")).toDouble() / 1000000.0);
+
+        const auto gidL = locObj.value(QLatin1String("gidL")).toArray();
+        for (const auto &gidV : gidL) {
+            const auto gid = gidV.toString() ;
+            // ### is this A× prefix actually standard or do we need to configure that per provider?
+            if (gid.startsWith(QStringLiteral("A×")) && IfoptUtil::isValid(QStringView(gid).mid(2))) {
+                loc.setIdentifier(IfoptUtil::identifierType(), gid.mid(2));
+            }
+        }
+
         locs.push_back(loc);
     }
     return locs;
@@ -508,7 +519,7 @@ static std::vector<Path> parsePaths(const QJsonArray &polyL, const std::vector<L
         // crdEncF: 1-dimensional, always 0?
 
         std::vector<PathSection> sections;
-        sections.reserve(std::max(0, ppLocRefL.size() - 1));
+        sections.reserve(std::max<int>(0, ppLocRefL.size() - 1));
         int prevPpIdx = 0;
         QPointF prevCoord;
         for (const auto &ppLocRefV : ppLocRefL) {
@@ -809,10 +820,14 @@ QDateTime HafasMgateParser::parseDateTime(const QString &date, const QJsonValue
 
     int dayOffset = 0;
     if (timeStr.size() > 6) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         dayOffset = timeStr.leftRef(timeStr.size() - 6).toInt();
+#else
+        dayOffset = QStringView(timeStr).left(timeStr.size() - 6).toInt();
+#endif
     }
 
-    auto dt = QDateTime::fromString(date + timeStr.rightRef(6), QStringLiteral("yyyyMMddhhmmss"));
+    auto dt = QDateTime::fromString(date + QStringView(timeStr).right(6), QStringLiteral("yyyyMMddhhmmss"));
     dt = dt.addDays(dayOffset);
     if (!tzOffset.isNull() && !tzOffset.isUndefined()) {
         dt.setOffsetFromUtc(tzOffset.toInt() * 60);
