@@ -77,15 +77,18 @@ bool JourneyReplyPrivate::needToWaitForAssets() const
 
 static bool isPointlessSection(const JourneySection &section)
 {
-    if (section.mode() == JourneySection::Walking || section.mode() == JourneySection::Waiting) {
+    if (section.mode() == JourneySection::Waiting) {
         return section.duration() < 60;
     }
+    if (section.mode() == JourneySection::Walking) {
+        return section.duration() < 60 && section.path().isEmpty();
+    }
     return false;
 }
 
 static bool isImplausibleSection(const JourneySection &section)
 {
-    if (section.mode() == JourneySection::Transfer) {
+    if (section.mode() == JourneySection::Transfer && section.from().hasCoordinate() && section.to().hasCoordinate()) {
         const auto distance = Location::distance(section.from(), section.to());
         if (section.duration() > 0 && (distance / section.duration()) > 30) {
             qCDebug(Log) << "discarding journey based on insane transfer speed:" << (distance / section.duration()) << "m/s";
@@ -242,7 +245,7 @@ void JourneyReply::addResult(const AbstractBackend *backend, std::vector<Journey
 
     // apply line meta data
     for (auto &jny : res) {
-        JourneyUtil::applyMetaData(jny, request().downloadAssets());
+        jny.applyMetaData(request().downloadAssets());
     }
 
     // cache negative hits, positive ones are too short-lived
