@@ -8,7 +8,6 @@
 #include "abstractquerymodel_p.h"
 
 #include <KPublicTransport/Attribution>
-#include <KPublicTransport/Vehicle>
 #include <KPublicTransport/VehicleLayoutReply>
 #include <KPublicTransport/Manager>
 
@@ -45,7 +44,7 @@ void VehicleLayoutQueryModelPrivate::doQuery()
     q->beginResetModel();
     m_stopover = m_request.stopover();
     q->endResetModel();
-    emit q->contentChanged();
+    Q_EMIT q->contentChanged();
 
     setLoading(true);
     auto reply = m_manager->queryVehicleLayout(m_request);
@@ -59,7 +58,7 @@ void VehicleLayoutQueryModelPrivate::doQuery()
             interpolatePlatformPositionsFromSectionName();
         }
         q->endResetModel();
-        emit q->contentChanged();
+        Q_EMIT q->contentChanged();
     });
 }
 
@@ -67,7 +66,7 @@ void VehicleLayoutQueryModelPrivate::doClearResults()
 {
     m_stopover = {};
     Q_Q(VehicleLayoutQueryModel);
-    emit q->contentChanged();
+    Q_EMIT q->contentChanged();
 }
 
 void VehicleLayoutQueryModelPrivate::interpolatePlatformPositionsFromSectionName()
@@ -156,7 +155,7 @@ void VehicleLayoutQueryModel::setRequest(const VehicleLayoutRequest &req)
 {
     Q_D(VehicleLayoutQueryModel);
     d->m_request = req;
-    emit requestChanged();
+    Q_EMIT requestChanged();
     d->query();
 }
 
@@ -176,11 +175,6 @@ Stopover VehicleLayoutQueryModel::stopover() const
     return d->m_stopover;
 }
 
-Stopover VehicleLayoutQueryModel::departure() const
-{
-    return stopover();
-}
-
 int VehicleLayoutQueryModel::rowCount(const QModelIndex &parent) const
 {
     Q_D(const VehicleLayoutQueryModel);
